/*
 * $Id: CollectionTester.java,v 1.1 2012/01/13 22:17:34 oboehm Exp $
 *
 * Copyright (c) 2012 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 13.01.2012 by oliver (ob@oasd.de)
 */

package patterntesting.runtime.junit;

import java.util.*;

import patterntesting.runtime.util.Converter;

/**
 * If you want to assert that the content of two collcections are equals use
 * this tester here.
 * 
 * @author oliver (ob@aosd.de)
 * @since 1.2 (13.01.2012)
 */
public final class CollectionTester {
    
    /** Utility class - no need to instantiate it. */
    private CollectionTester() {}
    
    /**
     * Checks if each object in collection c1 is equals to that of Collection c2.
     * If not this method will tell you which element is different.
     * If the collection have differnt size this method will tell you which
     * element is missing.
     *
     * @param c1 the c1
     * @param c2 the c2
     */
    public static void assertEquals(final Collection<?> c1, final Collection<?> c2) {        
        if (c1.size() < c2.size()) {
            assertEquals(c2, c1);
        } else if (c1.size() > c2.size()) {
            for (Object element : c1) {
                if (!c2.contains(element)) {
                    throw new AssertionError("\"" + Converter.toShortString(element)
                            + "\" is missing in " + Converter.toShortString(c2));
                }
            }
        } else {
            Iterator<?> iter1 = c1.iterator();
            Iterator<?> iter2 = c2.iterator();
            for (int i = 0; iter1.hasNext(); i++) {
                Object elem1 = iter1.next();
                Object elem2 = iter2.next();
                if (!elem1.equals(elem2)) {
                    throw new AssertionError((i+1) + ". element differs ("
                            + Converter.toShortString(elem1) + " != "
                            + Converter.toShortString(elem2) + ")");
                }
            }
        }
    }

}

